@@ -1,7 +1,7 @@
 # PurpleWiki::Database.pm
 # vi:sw=4:ts=4:ai:sm:et:tw=0
 #
-# $Id: Database.pm,v 1.5 2003/08/18 07:10:53 eekim Exp $
+# $Id: Database.pm 448 2004-08-06 11:25:09Z eekim $
 #
 # Copyright (c) Blue Oxen Associates 2002-2003.  All rights reserved.
 #
@@ -32,12 +32,13 @@ package PurpleWiki::Database;
 
 # PurpleWiki Page Data Access
 
-# $Id: Database.pm,v 1.5 2003/08/18 07:10:53 eekim Exp $
+# $Id: Database.pm 448 2004-08-06 11:25:09Z eekim $
 
 use strict;
+use PurpleWiki::Config;
 
-use vars qw($VERSION);
-$VERSION = '0.9';
+our $VERSION;
+$VERSION = sprintf("%d", q$Id: Database.pm 448 2004-08-06 11:25:09Z eekim $ =~ /\s(\d+)\s/);
 
 # Reads a string from a given filename and returns the data.
 # If it cannot open the file, it dies with an error.
@@ -46,7 +47,7 @@ sub ReadFileOrDie {
   my $fileName = shift;
   my ($status, $data);
 
-  ($status, $data) = &ReadFile($fileName);
+  ($status, $data) = ReadFile($fileName);
   if (!$status) {
     die("Can not open $fileName: $!");
   }
@@ -98,10 +99,11 @@ sub _GetDiff {
 # to mortals.
 # Private.
 sub _RequestLockDir {
-    my ($name, $tries, $wait, $errorDie, $config) = @_;
+    my ($name, $tries, $wait, $errorDie) = @_;
     my ($lockName, $n);
+    my $config = PurpleWiki::Config->instance();
 
-    &CreateDir($config->TempDir);
+    CreateDir($config->TempDir);
     $lockName = $config->LockDir . $name;
     $n = 0;
     while (mkdir($lockName, 0555) == 0) {
@@ -118,35 +120,34 @@ sub _RequestLockDir {
 # Removes the locking directory, destroying the lock
 # Private
 sub _ReleaseLockDir {
-    my ($name, $config) = @_;
+    my ($name) = @_;
+    my $config = PurpleWiki::Config->instance();
     rmdir($config->LockDir . $name);
 }
 
 # Requests a general editing lock for the system.
 # Public
 sub RequestLock {
-    my $config = shift;
     # 10 tries, 3 second wait, die on error
-    return &_RequestLockDir("main", 10, 3, 1, $config);
+    return _RequestLockDir("main", 10, 3, 1);
 }
 
 # Releases the general editing lock
 # Public
 sub ReleaseLock {
-    my $config = shift;
-    &_ReleaseLockDir('main', $config);
+    _ReleaseLockDir('main');
 }
 
 # Forces the lock to be released
 # Public
 sub ForceReleaseLock {
-    my ($name, $config) = @_;
+    my ($name) = @_;
     my $forced;
 
     # First try to obtain lock (in case of normal edit lock)
     # 5 tries, 3 second wait, do not die on error
-    $forced = !&_RequestLockDir($name, 5, 3, 0, $config);
-    &_ReleaseLockDir($name, $config);  # Release the lock, even if we didn't get it.
+    $forced = !_RequestLockDir($name, 5, 3, 0);
+    _ReleaseLockDir($name);  # Release the lock, even if we didn't get it.
     return $forced;
 }
 
@@ -175,7 +176,7 @@ sub AppendStringToFile {
 # wiki pages in the database.
 # Public
 sub AllPagesList {
-    my $config = shift;
+    my $config = PurpleWiki::Config->instance();
     my (@pages, @dirs, $id, $dir, @pageFiles, @subpageFiles, $subId);
 
     @pages = ();
@@ -194,20 +195,30 @@ sub AllPagesList {
         foreach $id (@pageFiles) {
             next  if (($id eq '.') || ($id eq '..'));
             if (substr($id, -3) eq '.db') {
-                push(@pages, substr($id, 0, -3));
+		my $pageName = substr($id, 0, -3);
+		$pageName =~ s/_/ /g if ($config->FreeLinks);
+                push(@pages, {
+		    'id' => substr($id, 0, -3),
+		    'pageName' => $pageName,
+                });
             } elsif (substr($id, -4) ne '.lck') {
                 opendir(PAGELIST, "$directory/$id");
                 @subpageFiles = readdir(PAGELIST);
                 closedir(PAGELIST);
                 foreach $subId (@subpageFiles) {
                     if (substr($subId, -3) eq '.db') {
-                        push(@pages, "$id/" . substr($subId, 0, -3));
+			my $pageName = "$id/" . substr($subId, 0, -3);
+			$pageName =~ s/_/ /g if ($config->FreeLinks);
+			push(@pages, {
+			    'id' => "$id/" . substr($subId, 0, -3),
+			    'pageName' => $pageName,
+			});
                     }
                 }
             }
         }
     }
-    return sort(@pages);
+    return sort { $a->{id} cmp $b->{id} } @pages;
 }
 
 # Updates the diffs keps for a page.
@@ -215,14 +226,15 @@ sub AllPagesList {
 sub UpdateDiffs {
     my $page = shift;
     my $keptRevision = shift;
-    my ($id, $editTime, $old, $new, $isEdit, $newAuthor, $config) = @_;
+    my ($id, $editTime, $old, $new, $isEdit, $newAuthor) = @_;
     my ($editDiff, $oldMajor, $oldAuthor);
+    my $config = PurpleWiki::Config->instance();
 
-    $editDiff  = &_GetDiff($old, $new, 0);     # 0 = already in lock
+    $editDiff  = _GetDiff($old, $new, 0);     # 0 = already in lock
     $oldMajor  = $page->getPageCache('oldmajor');
     $oldAuthor = $page->getPageCache('oldauthor');
     if ($config->UseDiffLog) {
-        &_WriteDiff($id, $editTime, $editDiff, $config);
+        _WriteDiff($id, $editTime, $editDiff);
     }
     $page->setPageCache('diff_default_minor', $editDiff);
 
@@ -230,7 +242,7 @@ sub UpdateDiffs {
         $page->setPageCache('diff_default_major', "1");
     } else {
         $page->setPageCache('diff_default_major',
-            &GetKeptDiff($keptRevision, $new, $oldMajor, 0));
+            GetKeptDiff($keptRevision, $new, $oldMajor, 0));
     }
 
     if ($newAuthor) {
@@ -241,7 +253,7 @@ sub UpdateDiffs {
         $page->setPageCache('diff_default_author', "2");
     } else {
         $page->setPageCache('diff_default_author',
-            &GetKeptDiff($keptRevision, $new, $oldAuthor, 0));
+            GetKeptDiff($keptRevision, $new, $oldAuthor, 0));
     }
 }
 
@@ -252,8 +264,8 @@ sub GetCacheDiff {
   my ($diffText);
 
   $diffText = $page->getPageCache("diff_default_$type");
-  $diffText = &GetCacheDiff($page, 'minor')  if ($diffText eq "1");
-  $diffText = &GetCacheDiff($page, 'major')  if ($diffText eq "2");
+  $diffText = GetCacheDiff($page, 'minor')  if ($diffText eq "1");
+  $diffText = GetCacheDiff($page, 'major')  if ($diffText eq "2");
   return $diffText;
 }
 
@@ -268,13 +280,14 @@ sub GetKeptDiff {
     my $oldText = $section->getText()->getText();
 
     return ""  if ($oldText eq "");  # Old revision not found
-    return &_GetDiff($oldText, $newText, $lock);
+    return _GetDiff($oldText, $newText, $lock);
 }
 
 # Writes out a diff to the diff log.
 # Private
 sub _WriteDiff {
-    my ($id, $editTime, $diffString, $config) = @_;
+    my ($id, $editTime, $diffString) = @_;
+    my $config = PurpleWiki::Config->instance();
 
     my $directory = $config->DataDir;
     open (OUT, ">>$directory/diff_log") or die('can not write diff_log');
@@ -283,5 +296,106 @@ sub _WriteDiff {
     close(OUT);
 }
 
+# Populates a hash reference with recent changes.
+# Data structure:
+#   $recentChanges = [
+#     { timeStamp => ,  # time stamp
+#       name => ,       # page name
+#       numChanges => , # number of times changed
+#       summary => ,    # change summary
+#       userName => ,   # username
+#       userId => ,     # user ID
+#       host => ,       # hostname
+#     },
+#     ...
+#   ]
+sub recentChanges {
+    my ($config, $timeStamp) = @_;
+    my @recentChanges;
+    my %pages;
+
+    # Default to showing all changes.
+    $timeStamp = 0 if not defined $timeStamp;
+
+    # Convert timeStamp to seconds since the epoch if it's not already in
+    # that form.
+    if (not $timeStamp =~ /^\d+$/) {
+        use Date::Manip;
+        $timeStamp = abs(UnixDate($timeStamp, "%o")) || 0;
+    }
+
+    ### FIXME: There's also an OldRcFile.  Should we read this also?
+    ### What is it for, anyway?
+    if (open(IN, $config->RcFile)) {
+    # parse logfile into pages hash
+        while (my $logEntry = <IN>) {
+            chomp $logEntry;
+            my $fsexp = $config->FS3;
+            my @entries = split /$fsexp/, $logEntry;
+            if (scalar @entries >= 6 && $entries[0] >= $timeStamp) {  # Check timestamp
+                my $name = $entries[1];
+                my $pageName = $name;
+
+                if ($config->FreeLinks) {
+                    $pageName =~ s/_/ /g;
+                }
+                if ( $pages{$name} &&
+                    ($pages{$name}->{timeStamp} > $entries[0]) ) {
+                    $pages{$name}->{numChanges}++;
+                }
+                else {
+                    if ($pages{$name}) {
+                        $pages{$name}->{numChanges}++;
+                    }
+                    else {
+                        $pages{$name}->{numChanges} = 1;
+                        $pages{$name}->{pageName} = $pageName;
+                    }
+                    $pages{$name}->{timeStamp} = $entries[0];
+                    if ($entries[2] ne '' && $entries[2] ne '*') {
+                        $pages{$name}->{summary} = $entries[2];
+                    }
+                    else {
+                        $pages{$name}->{summary} = '';
+                    }
+                    $pages{$name}->{minorEdit} = $entries[3];
+                    $pages{$name}->{host} = $entries[4];
+
+                    # $entries[5] is garbage and so we ignore it...
+
+                    # Get extra info
+                    my $fsexp = $config->FS2;
+                    my %userInfo = split /$fsexp/, $entries[6];
+                    if ($userInfo{id}) {
+                        $pages{$name}->{userId} = $userInfo{id};
+                    }
+                    else {
+                        $pages{$name}->{userId} = '';
+                    }
+                    if ($userInfo{name}) {
+                        $pages{$name}->{userName} = $userInfo{name};
+                    }
+                    else {
+                        $pages{$name}->{userName} = '';
+                    }
+                }
+            }
+        }
+        close(IN);
+
+    }
+    # now parse pages hash into final data structure and return
+    foreach my $name (sort { $pages{$b}->{timeStamp} <=> $pages{$a}->{timeStamp} } keys %pages) {
+        push @recentChanges, { timeStamp => $pages{$name}->{timeStamp},
+                               id => $name,
+                               pageName => $pages{$name}->{pageName},
+                               numChanges => $pages{$name}->{numChanges},
+                               summary => $pages{$name}->{summary},
+                               userName => $pages{$name}->{userName},
+                               userId => $pages{$name}->{userId},
+                               host => $pages{$name}->{host} };
+    }
+    return \@recentChanges;
+}
 
 1;
