@@ -1,6 +1,6 @@
 # PurpleWiki::InlineNode.pm
 #
-# $Id: InlineNode.pm,v 1.8 2003/08/18 07:10:53 eekim Exp $
+# $Id: InlineNode.pm 352 2004-05-08 22:00:33Z cdent $
 #
 # Copyright (c) Blue Oxen Associates 2002-2003.  All rights reserved.
 #
@@ -32,8 +32,8 @@ package PurpleWiki::InlineNode;
 use 5.005;
 use strict;
 
-use vars qw($VERSION);
-$VERSION = '0.9';
+our $VERSION;
+$VERSION = sprintf("%d", q$Id: InlineNode.pm 352 2004-05-08 22:00:33Z cdent $ =~ /\s(\d+)\s/);
 
 ### constructor
 
@@ -45,6 +45,7 @@ sub new {
     # TODO: Type checking.
     $self->{type} = $options{type} ? $options{type} : undef;
     $self->{href} = $options{href} ? $options{href} : undef;
+    $self->{class} = $options{class} ? $options{class} : undef;
     $self->{content} = $options{content} ? $options{content} : undef;
     $self->{children} = $options{children} ? $options{children} : undef;
     bless $self, $this;
@@ -67,6 +68,13 @@ sub href {
     return $this->{href};
 }
 
+sub class {
+    my $this = shift;
+
+    $this->{class} = shift if @_;
+    return $this->{class};
+}
+
 sub content {
     my $this = shift;
 
