@@ -1,7 +1,7 @@
 # PurpleWiki::Search::Arts.pm
 # vi:ai:sm:et:sw=4:ts=4
 #
-# $Id: Arts.pm,v 1.6 2004/01/21 23:24:08 cdent Exp $
+# $Id: Arts.pm 364 2004-05-19 18:15:26Z eekim $
 #
 # A Search Module for Arts (http://arts.sourceforge.net/) files
 # that have been formatted as PurpleWiki wikitext.
@@ -41,8 +41,8 @@ use base 'PurpleWiki::Search::Interface';
 use PurpleWiki::Search::Result;
 use IO::File;
 
-use vars qw($VERSION);
-$VERSION = '0.9.2';
+our $VERSION;
+$VERSION = sprintf("%d", q$Id: Arts.pm 364 2004-05-19 18:15:26Z eekim $ =~ /\s(\d+)\s/);
 
 my $FILE_MATCH = '\d+\.\d+\.wiki';
 
@@ -99,16 +99,16 @@ sub search {
 
                 # pack the results
                 my $result = new PurpleWiki::Search::Result();
-                $result->setTitle("$repository: $title");
-                $result->setURL($url);
-                $result->setSummary($summary);
-                $result->setModifiedTime((stat("$directory/$file"))[9]);
+                $result->title("$repository: $title");
+                $result->url($url);
+                $result->summary($summary);
+                $result->modifiedTime((stat("$directory/$file"))[9]);
                 push(@results, $result);
             }
         }
     }
 
-    @results = sort {$b->getModifiedTime() <=> $a->getModifiedTime()}
+    @results = sort {$b->modifiedTime() <=> $a->modifiedTime()}
         @results;
 
     return @results;
