@@ -1,8 +1,8 @@
 # PurpleWiki::View::xhtml.pm
 #
-# $Id: xhtml.pm,v 1.4 2003/08/18 07:10:54 eekim Exp $
+# $Id: xhtml.pm 366 2004-05-19 19:22:17Z eekim $
 #
-# Copyright (c) Blue Oxen Associates 2002-2003.  All rights reserved.
+# Copyright (c) Blue Oxen Associates 2002-2004.  All rights reserved.
 #
 # This file is part of PurpleWiki.  PurpleWiki is derived from:
 #
@@ -28,40 +28,54 @@
 #    Boston, MA 02111-1307 USA
 
 package PurpleWiki::View::xhtml;
-
 use 5.005;
 use strict;
-use PurpleWiki::Page;
-use PurpleWiki::Tree;
-use PurpleWiki::View::EventHandler;
+use warnings;
+use PurpleWiki::View::Driver;
 use PurpleWiki::View::wikihtml;
 
-use vars qw($VERSION);
-$VERSION = '0.9';
+############### Package Globals ###############
 
-# functions
+our $VERSION;
+$VERSION = sprintf("%d", q$Id: xhtml.pm 366 2004-05-19 19:22:17Z eekim $ =~ /\s(\d+)\s/);
+
+# Note that we don't inherit directly from Driver.pm like the other drivers.
+our @ISA = qw(PurpleWiki::View::wikihtml); 
+
+
+############### Overloaded Methods ###############
 
 sub view {
-    my ($wikiTree, %params) = @_;
+    my ($self, $wikiTree) = @_;
 
-    &PurpleWiki::View::wikihtml::registerHandlers;
-    return &_htmlHeader($wikiTree, %params) .
-        &PurpleWiki::View::EventHandler::view($wikiTree, %params) .
-        &_htmlFooter;
+    if (not defined $self->{css_file}) {
+        $self->{css_file} = "";
+    }
+
+    $self->SUPER::view($wikiTree);
+    $self->{outputString} = $self->_htmlHeader($wikiTree) .
+                            $self->{outputString} . $self->_htmlFooter();
+
+    return $self->{outputString};
 }
 
-# private
+
+############### Private Methods ###############
 
 sub _htmlHeader {
-    my ($wikiTree, %params) = @_;
+    my ($self, $wikiTree) = @_;
     my $outputString;
 
-    $outputString = "<html>\n<head>\n";
+    $outputString = qq(<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 ) .
+       qq(Strict//EN"\n) .
+       qq("http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">\n) .
+       qq(<html xmlns="http://www.w3.org/1999/xhtml" lang="en" xml:lang="en">) .
+       qq(<head>\n);
     $outputString .= '<title>' . $wikiTree->title . "</title>\n"
         if ($wikiTree->title);
-    if ($params{css_file}) {
+    if ($self->{css_file}) {
         $outputString .= '<link rel="stylesheet" href="';
-        $outputString .= $params{css_file};
+        $outputString .= $self->{css_file};
         $outputString .= '" type="text/css" />' . "\n";
     }
     $outputString .= "</head>\n<body>\n";
@@ -108,22 +122,45 @@ sub _htmlHeader {
 sub _htmlFooter {
     return "</body>\n</html>\n";
 }
-
 1;
 __END__
 
 =head1 NAME
 
-PurpleWiki::View::xhtml - XHTML view driver
+PurpleWiki::View::wikihtml - View Driver used for XHTML output.
+
+=head1 DESCRIPTION
+
+Converts a PurpleWiki::Tree into XHTML.  This object inherits from
+L<PurpleWiki::View::wikihtml>.
+
+=head1 METHODS
+
+=head2 new(url => $url, pageName => $pageName, css_file => $CSS)
+
+Returns a new PurpleWiki::View::xhtml object.
+
+url is the URL prepended to NIDs, defaults to the empty string. 
+
+pageName is the pageName used by sketch nodes for the SVG stuff, it defaults
+to the empty string.
+
+css_file is the name of the CSS file to use, defaults to the empty string.
+
+=head2 view($wikiTree)
+
+Returns the output as a string of valid XHTML.
 
 =head1 AUTHORS
 
+Matthew O'Connor, E<lt>matthew@canonical.orgE<gt>
+
 Chris Dent, E<lt>cdent@blueoxen.orgE<gt>
 
 Eugene Eric Kim, E<lt>eekim@blueoxen.orgE<gt>
 
 =head1 SEE ALSO
 
-L<PurpleWiki::View::EventHandler>.
+L<PurpleWiki::View::Driver>, L<PurpleWiki::View::wikihtml>
 
 =cut
