@@ -1,25 +1,37 @@
 #!/usr/bin/perl
 
 use IO::File;
+use Getopt::Long;
 use PurpleWiki::Config;
-use PurpleWiki::Parser::WikiText;
+
+my $useMoinMoin = 0;
+GetOptions('moinmoin' => \$useMoinMoin);
 
 if (@ARGV < 1) {
-  print "Usage: $0 config_dir wikifile.txt [output_driver]\n";
+  print "Usage: $0 [--moinmoin] config_dir wikifile.txt [output_driver]\n";
   exit;
 }
 
+($useMoinMoin) ? require PurpleWiki::Parser::MoinMoin :
+    require PurpleWiki::Parser::WikiText;
+
 my $config = PurpleWiki::Config->new($ARGV[0]);
 my $wikiContent = &readFile($ARGV[1]);
-my $wikiParser = PurpleWiki::Parser::WikiText->new;
-my $wiki = $wikiParser->parse($wikiContent, config=>$config, add_node_ids=>0);
+my $wikiParser;
+if ($useMoinMoin) {
+    $wikiParser = PurpleWiki::Parser::MoinMoin->new;
+}
+else {
+    $wikiParser = PurpleWiki::Parser::WikiText->new;
+}
+my $wiki = $wikiParser->parse($wikiContent, add_node_ids=>0);
 $wiki->title($ARGV[1]) if (!$wiki->title);
 
 if (@ARGV == 3) {
-    print $wiki->view($ARGV[2], config => $config);
+    print $wiki->view($ARGV[2]);
 }
 else {
-    print $wiki->view('debug', config => $config);
+    print $wiki->view('debug');
 }
 
 #$wiki->view('XHTML','collapse'=>[2]);
